@@ -1,7 +1,7 @@
 package Benchmark::Command;
 
 our $DATE = '2015-06-13'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -83,7 +83,7 @@ sub run {
     };
 
     # strip program's output
-    $output =~ /(.*)( +Rate\s+.+)/ms
+    $output =~ /(.*(?:^|\S))( +Rate\s+.+)/ms
         or die "Can't detect cmpthese() output, full output: $output";
 
     my $cmpoutput = $2;
@@ -123,7 +123,7 @@ Benchmark::Command - Benchmark commands
 
 =head1 VERSION
 
-This document describes version 0.06 of Benchmark::Command (from Perl distribution Benchmark-Command), released on 2015-06-13.
+This document describes version 0.07 of Benchmark::Command (from Perl distribution Benchmark-Command), released on 2015-06-13.
 
 =head1 SYNOPSIS
 
